Skip to contents

This function retrieves the downloadable merging template rows for a CatMapper merging template or related CMID.

Usage

getMergingTemplate(cmid, database = "SocioMap", url = NULL)

Arguments

cmid

A merging-template-related CMID accepted by the API route.

database

A string specifying the database from which to retrieve the template. Valid options are "SocioMap" or "ArchaMap".

url

API URL override. If NULL, CATMAPR_API_URL is used when set, otherwise "https://api.catmapper.org".

Value

A data frame with one row per template entry, including the instructional working-directory row.

Examples

if (FALSE) { # \dontrun{
getMergingTemplate(cmid = "AD354277", database = "ArchaMap")
} # }