Skip to contents

Polls the asynchronous CatMapper upload task endpoint and returns the current task state and any incremental events.

Usage

uploadInputNodesStatus(task_id, cursor = 0L, api_key = NULL, url = NULL)

Arguments

task_id

Upload task identifier returned by uploadInputNodes().

cursor

Optional event cursor used to request only new log messages.

api_key

API key used for authenticated write actions. If NULL, CATMAPR_API_KEY is used.

url

API URL override. If NULL, CATMAPR_API_URL is used when set.

Value

Parsed task-status payload.

Examples

if (FALSE) { # \dontrun{
uploadInputNodesStatus(
  task_id = "upload-task-id",
  api_key = Sys.getenv("CATMAPR_API_KEY")
)
} # }