For merging templates without variable mappings, writes long and wide link file sheets derived from the template's category merging ties.
Usage
downloadLinkFileWorkbook(
cmid,
database = "SocioMap",
path = NULL,
overwrite = FALSE,
url = NULL
)Arguments
- cmid
A MERGING CMID.
- database
A string specifying the database from which to retrieve the template. Valid options are
"SocioMap"or"ArchaMap".- path
Optional output workbook path. Defaults to
link_file_<CMID>.xlsxin the working directory.- overwrite
Whether to overwrite an existing file.
- url
API URL override.