Skip to contents

This function retrieves a structured summary for a MERGING or STACK node, including stack summaries, dataset summaries, merge ties, and category merging ties.

Usage

getMergingTemplateSummary(cmid, database = "SocioMap", url = NULL)

Arguments

cmid

A MERGING or STACK CMID.

database

A string specifying the database from which to retrieve the summary. Valid options are "SocioMap" or "ArchaMap".

url

API URL override. If NULL, CATMAPR_API_URL is used when set, otherwise "https://api.catmapper.org".

Value

A list with normalized stackSummary, datasetSummary, mergingTies, and categoryMergingTies data frames plus scalar summary fields returned by the API.

Examples

if (FALSE) { # \dontrun{
getMergingTemplateSummary(cmid = "AD354277", database = "ArchaMap")
} # }